#ifndef CL_STRINGS_H
#define CL_STRINGS_H

#define FIND_IN_FILES_WIN _("Search")
#define BUILD_WIN _("Build")
#define OUTPUT_WIN _("Output")
#define OUTPUT_DEBUG _("Debug")
#define REPLACE_IN_FILES _("Replace")
#define TASKS _("Tasks")
#define TRACE_TAB _("Trace")
#define SHOW_USAGE _("References")
#define TERMINAL_TAB _("Terminal")

// Panes
#define PANE_LEFT_SIDEBAR wxT("Workspace View")
#define PANE_RIGHT_SIDEBAR wxT("Secondary Sidebar")
#define PANE_DEBUGGER wxT("Debugger")
#define PANE_OUTPUT wxT("Output View")

#endif // CL_STRINGS_H
